Skip to contents

Check if the test parameters are compatible with a Q-matrix

Usage

check_test_parameters(test, qmatrix = NULL)

Arguments

test

item parameters matrix

qmatrix

Optional. If no qmatrix is passed, then it checks that it is compatible for some qmatrix

Value

boolean