Create a matrix of items and their parameters
Source:R/build_test_parameters.R
build_test_parameters.RdThis matrix already encodes the Q-matrix. It can be useful to save the results for future simulations or further wrangling as a csv.
R/build_test_parameters.R
build_test_parameters.RdThis matrix already encodes the Q-matrix. It can be useful to save the results for future simulations or further wrangling as a csv.