Check that the monotonicity condition of the gdina model is fullfilled. This is useful for when you don't want to force it, but you want to know if the model was able to achieve it.
Source:R/check_monotonicity.R
check_monotonicity.RdCheck that the monotonicity condition of the gdina model is fullfilled. This is useful for when you don't want to force it, but you want to know if the model was able to achieve it.