Returns a matrix of profiles and the probability of a correct response for all items.
Source:R/get_probabilities_by_profile.R
get_probabilities_by_profile.RdIt works by extraxcting the test parameters with get_test_parameters and
then passing that to the generate_responses(get_probs=TRUE) with all
possible mastery patterns to get the expected probabilities.